pub type BuiltinDef = FunctionDef<Builtin>;Expand description
A function definition for a function provided by the host.
Aliased Type
pub struct BuiltinDef {
pub offset: i32,
pub name: Arc<CStr>,
pub source: Arc<CStr>,
pub args: ArrayVec<Type, 8>,
pub body: Builtin,
}Fields
offset: i32The offset to the start of this function’s statements for QuakeC functions, the negative index of a builtin for functions provided by the host.
name: Arc<CStr>The name of this function.
source: Arc<CStr>The source file that this function is defined in.
args: ArrayVec<Type, 8>First N args get copied to the local stack.
body: BuiltinIf the function is defined in QuakeC, the function body.