FnCall

Struct FnCall 

pub struct FnCall<'a, T: ?Sized = dyn ErasedContext> { /* private fields */ }
The function call context, containing both the user context and the current VM context (which can be used to call into QuakeC functions).

Implementations

Source

impl<T: ?Sized> FnCall<'_, T>

pub fn context_mut(&mut self) -> &mut T

Explicitly get a mutable reference to the user-provided context. This is also available via the Deref/DerefMut implementation

Source

impl<T> FnCall<'_, T>
where T: ?Sized + AsErasedContext,

pub fn arguments(&self, args: &[Type]) -> impl Iterator<Item = Value>

Get an iterator of the arguments to this function. For now, the signature must be explicitly provided.

TODO: The signature should not need to be passed here.

Source

impl<'a, T> FnCall<'a, T>
where T: ErasedContext,

pub fn call<A, F>(&mut self, function_ref: F, args: A) -> Result<Value>
where F: Into<FunctionRef>, A: QCParams,

Call a QuakeC function by index or name.